@@ -1,8 +1,7 @@
 import numpy as np
 
-from setting import Setting
 from typing import Any, Dict
-from producer import Producer
+from cosecurity_amqp_lib.producer import Producer
 
 
 class Stub:
